==> pylucene-2.9.1-1-src.tar.gz: pylucene-2.9.1-1/lucene-java-2.9.1/src/java/org/apache/lucene/index/InvertedDocConsumer.java <==
package org.apache.lucene.index;

/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.Map;
import java.io.IOException;

abstract class InvertedDocConsumer {

  /** Add a new thread */
  abstract InvertedDocConsumerPerThread addThread(DocInverterPerThread docInverterPerThread);

  /** Abort (called after hitting AbortException) */
  abstract void abort();

  /** Flush a new segment */
  abstract void flush(Map threadsAndFields, SegmentWriteState state) throws IOException;

  /** Close doc stores */
  abstract void closeDocStore(SegmentWriteState state) throws IOException;

  /** Attempt to free RAM, returning true if any RAM was
   *  freed */
  abstract boolean freeRAM();

  FieldInfos fieldInfos;

  void setFieldInfos(FieldInfos fieldInfos) {
    this.fieldInfos = fieldInfos;
  }
}

==> pylucene-3.0.3-1-src.tar.gz: pylucene-3.0.3-1/lucene-java-3.0.3/src/java/org/apache/lucene/index/InvertedDocConsumer.java <==
package org.apache.lucene.index;

/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.Collection;
import java.util.Map;
import java.io.IOException;

abstract class InvertedDocConsumer {

  /** Add a new thread */
  abstract InvertedDocConsumerPerThread addThread(DocInverterPerThread docInverterPerThread);

  /** Abort (called after hitting AbortException) */
  abstract void abort();

  /** Flush a new segment */
  abstract void flush(Map<InvertedDocConsumerPerThread,Collection<InvertedDocConsumerPerField>> threadsAndFields, SegmentWriteState state) throws IOException;

  /** Close doc stores */
  abstract void closeDocStore(SegmentWriteState state) throws IOException;

  /** Attempt to free RAM, returning true if any RAM was
   *  freed */
  abstract boolean freeRAM();

  FieldInfos fieldInfos;

  void setFieldInfos(FieldInfos fieldInfos) {
    this.fieldInfos = fieldInfos;
  }
}
